MCALF: Multi-Component Atmospheric Line Fitting
***********************************************

MCALF Documentation
===================

Welcome to MCALF's documentation!

MCALF is an open-source Python package for accurately constraining
velocity information from spectral imaging observations using
machine learning techniques.

These pages document how the package can be interacted with.
Some examples are also provided.
A :any:`Documentation Index <genindex>` and
a :any:`Module Index <modindex>` are available.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide/index
   gallery/index
   code_ref/index
   code_of_conduct
   license
